@@ -13,21 +13,22 @@ import Data.Int (Int64)
 import qualified Data.Text as S
 import qualified Data.Text.Lazy as L
 import qualified Data.Text.Read
+import Data.Time (Day)
 
 class PathPiece s where
     fromPathPiece :: S.Text -> Maybe s
     toPathPiece :: s -> S.Text
 
 instance PathPiece String where
-    fromPathPiece s = if S.null s then Nothing else Just (S.unpack s)
+    fromPathPiece = Just . S.unpack
     toPathPiece = S.pack
 
 instance PathPiece S.Text where
-    fromPathPiece s = if S.null s then Nothing else Just s
+    fromPathPiece = Just
     toPathPiece = id
 
 instance PathPiece L.Text where
-    fromPathPiece s = if S.null s then Nothing else Just (L.fromChunks [s])
+    fromPathPiece = Just . L.fromChunks . return
     toPathPiece = S.concat . L.toChunks
 
 instance PathPiece Integer where
@@ -51,6 +52,12 @@ instance PathPiece Int64 where
             Left _ -> Nothing
     toPathPiece = S.pack . show
 
+instance PathPiece Day where
+    fromPathPiece t =
+        case reads $ S.unpack t of
+            [(a,"")] -> Just a
+            _ -> Nothing
+    toPathPiece = S.pack . show
 
 class PathMultiPiece s where
     fromPathMultiPiece :: [S.Text] -> Maybe s
